@@ -1,2 +1,2 @@
-from sdog.watcher import main
+from sdog.monitor import main
 from sdog.notifier import SDNotifier
